@@ -29,6 +29,8 @@ def _check_assertions(assertions: Sequence[Expression]) -> bool:
     transformer._top_level = False
 
     expr = expressions.And(*assertions)
+    if expr.is_concrete:
+        return expr.value
     result = transformer.visit(expr)
     if result.is_concrete and not result.value:
         return False
@@ -343,6 +345,11 @@ class DetailsInference(ExpressionVisitor):
         dtype = self.types[expression.expression]
         self.set_details(expression, shape=shape, dtype=dtype)
 
+    def visit_ExtSlice(self, expression: expressions.ExtSlice):
+        for expr in expression.expressions:
+            self.visit(expr)
+        self.set_details(expression, shape=Constant(()), dtype=Constant(tuple))
+
     def visit_Forall(self, expression: expressions.Forall):
         self.visit(expression.expression)
         self.visit(expression.variable)
@@ -441,7 +448,7 @@ class DetailsInference(ExpressionVisitor):
         self.assertions.extend(shape_assertions)
         if not _check_assertions(type_assertions):
             raise DNNVTypeError(
-                f"Incompatible types in Implies: {self.types[expression.expr1].value} and {self.types[expression.expr1].value}"
+                f"Incompatible types in Implies: {self.types[expression.expr1].value} and {self.types[expression.expr2].value}"
             )
         self.assertions.extend(type_assertions)
 
