@@ -1,9 +1,12 @@
 from abc import ABC, abstractmethod
-from typing import Any, Generator, Optional, Tuple, Type
+from typing import Any, Iterator, Optional, Tuple, Type
 
+from dnnv.errors import DNNVError
 from dnnv.properties import Expression
 
-from ..errors import VerifierTranslatorError
+
+class ReductionError(DNNVError):
+    pass
 
 
 class Property:
@@ -15,13 +18,13 @@ class Property:
 class Reduction(ABC):
     def __init__(
         self,
-        reduction_error: Type[VerifierTranslatorError] = VerifierTranslatorError,
+        reduction_error: Type[ReductionError] = ReductionError,
     ):
         self.reduction_error = reduction_error
 
     @abstractmethod
-    def reduce_property(self, phi: Expression) -> Generator[Property, None, None]:
+    def reduce_property(self, phi: Expression) -> Iterator[Property]:
         raise NotImplementedError()
 
 
-__all__ = ["Property", "Reduction"]
+__all__ = ["Property", "Reduction", "ReductionError"]
